Processor.App.OutStreamer.dummy\_streamer.DummyStreamer
=======================================================

.. currentmodule:: Processor.App.OutStreamer.dummy_streamer

.. autoclass:: DummyStreamer

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:

   
      ~DummyStreamer.__init__
      ~DummyStreamer.clean_up
      ~DummyStreamer.stream
   
   

   
   
   